@@ -5,7 +5,9 @@ algorithm_new <- function(
   shortcut = NULL,
   queue = NULL,
   reporter = NULL,
-  seconds_interval = NULL
+  seconds_meta_append = NULL,
+  seconds_meta_upload = NULL,
+  seconds_reporter = NULL
 ) {
   algorithm_class$new(
     pipeline = pipeline,
@@ -14,7 +16,9 @@ algorithm_new <- function(
     shortcut = shortcut,
     queue = queue,
     reporter = reporter,
-    seconds_interval = seconds_interval
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter
   )
 }
 
@@ -30,7 +34,9 @@ algorithm_class <- R6::R6Class(
     shortcut = NULL,
     queue = NULL,
     reporter = NULL,
-    seconds_interval = NULL,
+    seconds_meta_append = NULL,
+    seconds_meta_upload = NULL,
+    seconds_reporter = NULL,
     initialize = function(
       pipeline = NULL,
       meta = NULL,
@@ -38,7 +44,9 @@ algorithm_class <- R6::R6Class(
       shortcut = NULL,
       queue = NULL,
       reporter = NULL,
-      seconds_interval = NULL
+      seconds_meta_append = NULL,
+      seconds_meta_upload = NULL,
+      seconds_reporter = NULL
     ) {
       self$pipeline <- pipeline
       self$meta <- meta
@@ -46,7 +54,9 @@ algorithm_class <- R6::R6Class(
       self$shortcut <- shortcut
       self$queue <- queue
       self$reporter <- reporter
-      self$seconds_interval <- seconds_interval
+      self$seconds_meta_append <- seconds_meta_append
+      self$seconds_meta_upload <- seconds_meta_upload
+      self$seconds_reporter <- seconds_reporter
     },
     update_scheduler = function() {
       self$scheduler <- scheduler_init(
@@ -54,7 +64,7 @@ algorithm_class <- R6::R6Class(
         meta = self$meta,
         queue = self$queue,
         reporter = self$reporter,
-        seconds_interval = self$seconds_interval,
+        seconds_reporter = self$seconds_reporter,
         names = self$names,
         shortcut = self$shortcut
       )
@@ -71,6 +81,17 @@ algorithm_class <- R6::R6Class(
       tar_assert_chr(self$names %|||% character(0))
       tar_assert_chr(self$queue %|||% character(0))
       tar_assert_chr(self$reporter %|||% character(0))
+      fields <- c(
+        "seconds_meta_append",
+        "seconds_meta_upload",
+        "seconds_reporter"
+      )
+      for (field in fields) {
+        tar_assert_dbl(self[[field]])
+        tar_assert_scalar(self[[field]])
+        tar_assert_none_na(self[[field]])
+        tar_assert_ge(self[[field]], 0)
+      }
     }
   )
 )
