@@ -24,9 +24,6 @@ sequential_class <- R6::R6Class(
     append = function(names, ranks = NULL) {
       self$data <- c(self$data, names)
     },
-    append0 = function(name) {
-      self$data[length(self$data) + 1L] <- name
-    },
     should_dequeue = function() {
       self$is_nonempty()
     },
