@@ -4,10 +4,6 @@
 #' @description List targets whose progress is `"canceled"`.
 #' @return A character vector of canceled targets.
 #' @inheritParams tar_progress
-#' @param names Optional, names of the targets. If supplied, the
-#'   function restricts its output to these targets.
-#'   You can supply symbols
-#'   or `tidyselect` helpers like [any_of()] and [starts_with()].
 #' @examples
 #' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) { # for CRAN
 #' tar_dir({ # tar_dir() runs code from a temp dir for CRAN.
@@ -26,7 +22,7 @@ tar_canceled <- function(
   names = NULL,
   store = targets::tar_config_get("store")
 ) {
-  tar_assert_allow_meta("tar_canceled")
+  tar_assert_allow_meta("tar_canceled", store)
   progress <- progress_init(path_store = store)
   progress <- tibble::as_tibble(progress$database$read_condensed_data())
   names_quosure <- rlang::enquo(names)
