@@ -88,7 +88,8 @@ tar_config_get_project <- function(name, yaml) {
     inherits = yaml$inherits,
     as_job = yaml$as_job %|||% FALSE,
     garbage_collection = yaml$garbage_collection %|||% FALSE,
-    label = yaml$label,
+    label = yaml$label %|||% "description",
+    label_width = yaml$label_width %|||% 30L,
     level_separation = yaml$level_separation,
     reporter_make = yaml$reporter_make %|||% "verbose",
     reporter_outdated = yaml$reporter_outdated %|||% "silent",
@@ -110,7 +111,8 @@ tar_config_get_convert <- function(name, value) {
     inherits = if_any(is.null(value), NULL, as.character(value)),
     as_job = as.logical(value),
     garbage_collection = as.logical(value),
-    label = if_any(is.null(value), NULL, as.character(value)),
+    label = as.character(value),
+    label_width = if_any(is.null(value), NULL, as.integer(value)),
     level_separation = if_any(is.null(value), NULL, as.numeric(value)),
     reporter_make = as.character(value),
     reporter_outdated = as.character(value),
