@@ -37,6 +37,11 @@
 #'   defaults to `Sys.getenv("TAR_PROJECT", "main")`.
 #'   If the `inherits` argument `NULL`, the `inherits` setting is not modified.
 #'   Use [tar_config_unset()] to delete a setting.
+#' @param as_job Logical of length 1, `as_job` argument of [tar_make()].
+#'   `TRUE` to run as an RStudio IDE / Posit Workbench job,
+#'   `FALSE` to run as a `callr` process in the main R session
+#'   (depending on the `callr_function` argument).
+#'   If `as_job_` is `TRUE`, then the `rstudioapi` package must be installed.
 #' @param garbage_collection Logical of length 1, `garbage_collection`
 #'   argument of [tar_make()] (if `crew` is enabled),
 #'   [tar_make_clustermq()], and [tar_make_future()].
@@ -46,7 +51,11 @@
 #'   ignored if `tar_option_get("controller")` is `NULL`.
 #'   Independent from the `garbage_collection` argument of [tar_target()],
 #'   which controls garbage collection on the worker.
-#' @param label Argument of [tar_visnetwork()] to control node labels.
+#' @param label Argument of [tar_glimpse()] and [tar_visnetwork()]
+#'   to control node labels.
+#' @param label_width Argument of [tar_glimpse()] and [tar_visnetwork()]
+#'   to control the maximum width (number of characters wide)
+#'   of the node labels.
 #' @param level_separation Argument of [tar_visnetwork()] and [tar_glimpse()]
 #'   to control the space between hierarchical levels.
 #' @param reporter_make Character of length 1, `reporter` argument to
@@ -161,8 +170,10 @@
 #' }
 tar_config_set <- function(
   inherits = NULL,
+  as_job = NULL,
   garbage_collection = NULL,
   label = NULL,
+  label_width = NULL,
   level_separation = NULL,
   reporter_make = NULL,
   reporter_outdated = NULL,
@@ -185,8 +196,10 @@ tar_config_set <- function(
   tar_assert_chr(project)
   tar_assert_scalar(project)
   tar_config_assert_inherits(inherits)
+  tar_config_assert_as_job(as_job)
   tar_config_assert_garbage_collection(garbage_collection)
   tar_config_assert_label(label)
+  tar_config_assert_label_width(label_width)
   tar_config_assert_level_separation(level_separation)
   tar_config_assert_reporter_make(reporter_make)
   tar_config_assert_reporter_outdated(reporter_outdated)
@@ -201,9 +214,11 @@ tar_config_set <- function(
   tar_config_assert_workers(workers)
   yaml <- tar_config_yaml(config = config)
   yaml[[project]]$inherits <- inherits %|||% yaml[[project]]$inherits
+  yaml[[project]]$as_job <- as_job %|||% yaml[[project]]$as_job
   yaml[[project]]$garbage_collection <- garbage_collection %|||%
     yaml[[project]]$garbage_collection
   yaml[[project]]$label <- label %|||% yaml[[project]]$label
+  yaml[[project]]$label_width <- label_width %|||% yaml[[project]]$label_width
   yaml[[project]]$level_separation <- level_separation %|||%
     yaml[[project]]$level_separation
   yaml[[project]]$reporter_make <- reporter_make %|||%
@@ -246,6 +261,15 @@ tar_config_assert_inherits <- function(inherits) {
   tar_assert_nzchar(inherits)
 }
 
+tar_config_assert_as_job <- function(as_job) {
+  if (is.null(as_job)) {
+    return()
+  }
+  tar_assert_lgl(as_job)
+  tar_assert_scalar(as_job)
+  tar_assert_none_na(as_job)
+}
+
 tar_config_assert_garbage_collection <- function(garbage_collection) {
   if (is.null(garbage_collection)) {
     return()
@@ -264,6 +288,16 @@ tar_config_assert_label <- function(label) {
   tar_assert_nzchar(label)
 }
 
+tar_config_assert_label_width <- function(label_width) {
+  if (is.null(label_width)) {
+    return()
+  }
+  tar_assert_dbl(label_width)
+  tar_assert_ge(label_width, 1L)
+  tar_assert_none_na(label_width)
+  tar_assert_scalar(label_width)
+}
+
 tar_config_assert_level_separation <- function(level_separation) {
   if (is.null(level_separation)) {
     return()
