@@ -94,6 +94,7 @@
 #'   `tar_option_get("controller")$summary()` to close down the dispatcher
 #'   and worker processes.
 #' @param as_job `TRUE` to run as an RStudio IDE / Posit Workbench job,
+#'   if running on RStudio IDE / Posit Workbench.
 #'   `FALSE` to run as a `callr` process in the main R session
 #'   (depending on the `callr_function` argument).
 #'   If `as_job` is `TRUE`, then the `rstudioapi` package must be installed.
@@ -171,6 +172,9 @@ tar_make <- function(
   tar_assert_none_na(as_job)
   # Tested in tests/interactive/test-job.R.
   # nocov start
+  if (as_job && !rstudio_available(verbose = reporter != "silent")) {
+    as_job <- FALSE
+  }
   if (as_job) {
     call <- match.call()
     tar_make_as_job(call = call)
@@ -260,29 +264,6 @@ tar_make_inner <- function(
 # Tested in tests/interactive/test-job.R.
 # nocov start
 tar_make_as_job <- function(call) {
-  tar_assert_package(
-    "rstudioapi",
-    msg = paste(
-      "The 'rstudioapi' package is required to run tar_make()",
-      "with as_job = TRUE. Either install the package or set as_job = FALSE.",
-      "You can set as_job = FALSE either manually",
-      "in tar_make() or persistently",
-      "for the project in _targets.yaml",
-      "using tar_config_set(as_job = FALSE)."
-    )
-  )
-  tar_assert_true(
-    rstudioapi::isAvailable(),
-    msg = paste(
-      "tar_make(as_job = TRUE) can only run inside the RStudio IDE",
-      "or Posit Workbench. If you are running the pipeline in a terminal",
-      "or a different IDE, then please set as_job = FALSE.",
-      "You can set as_job = FALSE either manually",
-      "in tar_make() or persistently",
-      "for the project in _targets.yaml",
-      "using tar_config_set(as_job = FALSE)."
-    )
-  )
   args <- as.list(call)[-1L]
   args$as_job <- FALSE
   args <- paste(names(args), "=", map_chr(args, tar_deparse_safe))
