@@ -1,4 +1,4 @@
-test_that("tar_config_projects()", {
+tar_test("tar_config_projects()", {
   yaml <- tempfile()
   tar_config_set(store = "my_store_a", config = yaml, project = "project_a")
   tar_config_set(store = "my_store_b", config = yaml, project = "project_b")
